QGamiCore class

Properties

hashCode int
The hash code for this object.
no setterinherited
isIdentified bool
no setter
isInitialized bool
no setter
isReady bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGameUrl({required String gameSlug}) Future<String?>
getInitGameMessage({String? gameSlug, required String mode, required bool showCloseBtn, required double paddingTop, required double paddingBottom}) Map<String, dynamic>
getUpdateAccessTokenMessage({required String accessToken}) Map<String, dynamic>
identify({required String email, required String username, required String userId}) Future<bool>
initialize({required String apiKey, required String environment, required String locale}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openGame(BuildContext context, {required String? url, required String gameSlug}) → void
openHub() → void
refreshAccessToken() Future<String?>
showFloatingWidget() → void
toString() String
A string representation of this object.
inherited
waitUntilReady({Duration timeout = const Duration(seconds: 15)}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance QGamiCore
final